@@ -25,12 +25,17 @@
 
 #include <gcrypt.h>
 
+struct _Gsasl_cram_md5_client_state
+{
+  int step;
+};
+
 int
-_gsasl_cram_md5_client_init (Gsasl_ctx *ctx)
+_gsasl_cram_md5_client_init (Gsasl_ctx * ctx)
 {
   int res;
 
-  if (gcry_check_version(GCRYPT_VERSION) == NULL)
+  if (gcry_check_version (GCRYPT_VERSION) == NULL)
     return GSASL_GCRYPT_ERROR;
 
   res = gcry_control (GCRYCTL_INIT_SECMEM, 512, 0);
@@ -41,17 +46,16 @@ _gsasl_cram_md5_client_init (Gsasl_ctx *ctx)
 }
 
 void
-_gsasl_cram_md5_client_done (Gsasl_ctx *ctx)
+_gsasl_cram_md5_client_done (Gsasl_ctx * ctx)
 {
   return;
 }
 
 int
-_gsasl_cram_md5_client_start (Gsasl_session_ctx *cctx, 
-			      void **mech_data)
+_gsasl_cram_md5_client_start (Gsasl_session_ctx * cctx, void **mech_data)
 {
+  struct _Gsasl_cram_md5_client_state *state;
   Gsasl_ctx *ctx;
-  int *done;
 
   ctx = gsasl_client_ctx_get (cctx);
   if (ctx == NULL)
@@ -63,26 +67,25 @@ _gsasl_cram_md5_client_start (Gsasl_session_ctx *cctx,
   if (gsasl_client_callback_password_get (ctx) == NULL)
     return GSASL_NEED_CLIENT_PASSWORD_CALLBACK;
 
-  done = (int*) malloc(sizeof(*done));
-  if (done == NULL)
+  state = malloc (sizeof (*state));
+  if (state == NULL)
     return GSASL_MALLOC_ERROR;
 
-  *done = 0;
+  state->step = 0;
+
+  *mech_data = state;
 
-  *mech_data = done;
-  
   return GSASL_OK;
 }
 
 int
-_gsasl_cram_md5_client_step  (Gsasl_session_ctx *cctx, 
-			      void *mech_data, 
-			      const char *input,
-			      size_t input_len,
-			      char *output,
-			      size_t *output_len)
+_gsasl_cram_md5_client_step (Gsasl_session_ctx * cctx,
+			     void *mech_data,
+			     const char *input,
+			     size_t input_len,
+			     char *output, size_t * output_len)
 {
-  int *step = mech_data;
+  struct _Gsasl_cram_md5_client_state *state = mech_data;
   Gsasl_ctx *ctx;
   Gsasl_client_callback_authentication_id cb_authentication_id;
   Gsasl_client_callback_password cb_password;
@@ -94,88 +97,88 @@ _gsasl_cram_md5_client_step  (Gsasl_session_ctx *cctx,
   int i;
   int res;
 
-  if (*step > 0)
-    return GSASL_OK;
-
-  if (input_len == 0)
+  switch(state->step)
     {
-      *output_len = 0;
-      return GSASL_NEEDS_MORE;
+    case 0:
+      ctx = gsasl_client_ctx_get (cctx);
+      if (ctx == NULL)
+	return GSASL_CANNOT_GET_CTX;
+
+      cb_authentication_id = gsasl_client_callback_authentication_id_get (ctx);
+      if (cb_authentication_id == NULL)
+	return GSASL_NEED_CLIENT_AUTHENTICATION_ID_CALLBACK;
+
+      cb_password = gsasl_client_callback_password_get (ctx);
+      if (cb_password == NULL)
+	return GSASL_NEED_CLIENT_PASSWORD_CALLBACK;
+
+      md5h = gcry_md_open (GCRY_MD_MD5, GCRY_MD_FLAG_SECURE|GCRY_MD_FLAG_HMAC);
+      if (md5h == NULL)
+	return GSASL_GCRYPT_ERROR;
+
+      /* XXX? password stored in callee's output buffer */
+      len = *output_len;
+      res = cb_password (cctx, output, &len);
+      if (res != GSASL_OK)
+	return res;
+      tmp = stringprep_utf8_nfkc_normalize (output, len);
+      if (tmp == NULL)
+	return GSASL_UNICODE_NORMALIZATION_ERROR;
+      res = gcry_md_setkey (md5h, tmp, strlen (tmp));
+      free (tmp);
+      if (res != GCRYERR_SUCCESS)
+	return GSASL_GCRYPT_ERROR;
+
+      gcry_md_write (md5h, input, input_len);
+
+      hash = gcry_md_read (md5h, GCRY_MD_MD5);
+      if (hash == NULL)
+	return GSASL_GCRYPT_ERROR;
+
+      len = *output_len;
+      res = cb_authentication_id (cctx, output, &len);
+      if (res != GSASL_OK)
+	return res;
+      tmp = stringprep_utf8_nfkc_normalize (output, len);
+      if (tmp == NULL)
+	return GSASL_UNICODE_NORMALIZATION_ERROR;
+      if (strlen (tmp) + strlen (" ") + 2 * hash_len >= *output_len)
+	{
+	  free (tmp);
+	  return GSASL_TOO_SMALL_BUFFER;
+	}
+      len = strlen (tmp);
+      memcpy (output, tmp, len);
+      free (tmp);
+      output[len++] = ' ';
+
+      for (i = 0; i < hash_len; i++)
+	{
+	  output[len + 2 * i + 1] = HEXCHAR (hash[i]);
+	  output[len + 2 * i + 0] = HEXCHAR (hash[i] >> 4);
+	}
+      *output_len = len + 2 * hash_len;
+      
+      gcry_md_close (md5h);
+
+      state->step++;
+      res = GSASL_OK;
+      break;
+
+    default:
+      res = GSASL_MECHANISM_CALLED_TOO_MANY_TIMES;
+      break;
     }
 
-  ctx = gsasl_client_ctx_get (cctx);
-  if (ctx == NULL)
-    return GSASL_CANNOT_GET_CTX;
-
-  cb_authentication_id = gsasl_client_callback_authentication_id_get (ctx);
-  if (cb_authentication_id == NULL)
-    return GSASL_NEED_CLIENT_AUTHENTICATION_ID_CALLBACK;
-
-  cb_password = gsasl_client_callback_password_get (ctx);
-  if (cb_password == NULL)
-    return GSASL_NEED_CLIENT_PASSWORD_CALLBACK;
-
-  md5h = gcry_md_open (GCRY_MD_MD5, GCRY_MD_FLAG_HMAC);
-  if (md5h == NULL)
-    return GSASL_GCRYPT_ERROR;
-    
-  /* XXX? password stored in callee's output buffer */
-  len = *output_len;
-  res = cb_password (cctx, output, &len); 
-  if (res != GSASL_OK)
-    return res;
-  tmp = gsasl_utf8_nfkc_normalize (output, len);
-  if (tmp == NULL)
-    return GSASL_UNICODE_NORMALIZATION_ERROR;
-  res = gcry_md_setkey (md5h, tmp, strlen(tmp));
-  free(tmp);
-  if (res != GCRYERR_SUCCESS)
-    return GSASL_GCRYPT_ERROR;
-
-  gcry_md_write (md5h, input, input_len);
-  
-  hash = gcry_md_read (md5h, GCRY_MD_MD5);
-  if (hash == NULL)
-    return GSASL_GCRYPT_ERROR;
-
-  len = *output_len;
-  res = cb_authentication_id (cctx, output, &len);
-  if (res != GSASL_OK)
-    return res;
-  tmp = gsasl_utf8_nfkc_normalize (output, len);
-  if (tmp == NULL)
-    return GSASL_UNICODE_NORMALIZATION_ERROR;
-  if (strlen(tmp) + strlen(" ") + 2*hash_len >= *output_len)
-    {
-      free(tmp);
-      return GSASL_TOO_SMALL_BUFFER;
-    }
-  len = strlen(tmp);
-  memcpy(output, tmp, len);
-  free(tmp);
-  output[len++] = ' ';
-
-  for (i = 0; i < hash_len; i++)
-    {
-      output[len + 2*i + 1] = HEXCHAR(hash[i]);
-      output[len + 2*i + 0] = HEXCHAR(hash[i] >> 4);
-    }
-  *output_len = len + 2*hash_len;
-
-  gcry_md_close(md5h);
-
-  (*step)++;
-
-  return GSASL_NEEDS_MORE;
+  return res;
 }
 
 int
-_gsasl_cram_md5_client_finish (Gsasl_session_ctx *cctx,
-			    void *mech_data)
+_gsasl_cram_md5_client_finish (Gsasl_session_ctx * cctx, void *mech_data)
 {
-  int *step = mech_data;
+  struct _Gsasl_cram_md5_client_state *state = mech_data;
 
-  free(step);
+  free (state);
 
   return GSASL_OK;
 }
@@ -183,23 +186,22 @@ _gsasl_cram_md5_client_finish (Gsasl_session_ctx *cctx,
 /* Server */
 
 int
-_gsasl_cram_md5_server_init (Gsasl_ctx *ctx)
+_gsasl_cram_md5_server_init (Gsasl_ctx * ctx)
 {
-  if (gcry_check_version(GCRYPT_VERSION) == NULL)
+  if (gcry_check_version (GCRYPT_VERSION) == NULL)
     return GSASL_GCRYPT_ERROR;
 
   return GSASL_OK;
 }
 
 void
-_gsasl_cram_md5_server_done (Gsasl_ctx *ctx)
+_gsasl_cram_md5_server_done (Gsasl_ctx * ctx)
 {
   return;
 }
 
 int
-_gsasl_cram_md5_server_start (Gsasl_session_ctx *sctx, 
-			      void **mech_data)
+_gsasl_cram_md5_server_start (Gsasl_session_ctx * sctx, void **mech_data)
 {
   Gsasl_ctx *ctx;
   char *challenge;
@@ -219,34 +221,32 @@ _gsasl_cram_md5_server_start (Gsasl_session_ctx *sctx,
 #define NUMBER_OF_XS 16
 #define CHALLENGE_FORMAT "<XXXXXXXXXXXXXXXX.libgsasl@localhost>"
 
-  challenge = (char*) malloc(strlen(CHALLENGE_FORMAT) + 1);
+  challenge = (char *) malloc (strlen (CHALLENGE_FORMAT) + 1);
   if (challenge == NULL)
     return GSASL_MALLOC_ERROR;
 
-  strcpy(challenge, CHALLENGE_FORMAT);
+  strcpy (challenge, CHALLENGE_FORMAT);
 
   gcry_randomize (challenge + 1, NUMBER_OF_XS, GCRY_WEAK_RANDOM);
 
-  for (i = 0; i < NUMBER_OF_XS/2; i++)
+  for (i = 0; i < NUMBER_OF_XS / 2; i++)
     {
-      challenge[START_OF_XS + NUMBER_OF_XS/2 + i] = 
-	HEXCHAR(challenge[START_OF_XS + i]);
-      challenge[START_OF_XS + i] = 
-	HEXCHAR(challenge[START_OF_XS + i] >> 4);
+      challenge[START_OF_XS + NUMBER_OF_XS / 2 + i] =
+	HEXCHAR (challenge[START_OF_XS + i]);
+      challenge[START_OF_XS + i] = HEXCHAR (challenge[START_OF_XS + i] >> 4);
     }
-  
+
   *mech_data = challenge;
 
   return GSASL_OK;
 }
 
 int
-_gsasl_cram_md5_server_step (Gsasl_session_ctx *sctx, 
-			     void *mech_data, 
+_gsasl_cram_md5_server_step (Gsasl_session_ctx * sctx,
+			     void *mech_data,
 			     const char *input,
 			     size_t input_len,
-			     char *output,
-			     size_t *output_len)
+			     char *output, size_t * output_len)
 {
   char *challenge = mech_data;
   Gsasl_server_callback_cram_md5 cb_cram_md5;
@@ -258,11 +258,11 @@ _gsasl_cram_md5_server_step (Gsasl_session_ctx *sctx,
 
   if (input_len == 0)
     {
-      if (*output_len < strlen(challenge))
+      if (*output_len < strlen (challenge))
 	return GSASL_TOO_SMALL_BUFFER;
-      
-      *output_len = strlen(challenge);
-      memcpy(output, challenge, *output_len);
+
+      *output_len = strlen (challenge);
+      memcpy (output, challenge, *output_len);
 
       return GSASL_NEEDS_MORE;
     }
@@ -282,30 +282,30 @@ _gsasl_cram_md5_server_step (Gsasl_session_ctx *sctx,
   if (cb_cram_md5 == NULL && cb_retrieve == NULL)
     return GSASL_NEED_SERVER_CRAM_MD5_CALLBACK;
 
-  username = (char*) malloc(input_len);
+  username = (char *) malloc (input_len);
   if (username == NULL)
     return GSASL_MALLOC_ERROR;
 
-  memcpy(username, input, input_len - hash_len * 2);
+  memcpy (username, input, input_len - hash_len * 2);
   username[input_len - hash_len * 2 - 1] = '\0';
 
   if (cb_cram_md5)
     {
       char *response;
 
-      response = (char*) malloc(hash_len * 2 + 1);
+      response = (char *) malloc (hash_len * 2 + 1);
       if (response == NULL)
 	{
-	  free(username);
+	  free (username);
 	  return GSASL_MALLOC_ERROR;
 	}
 
-      memcpy(response, input + input_len - hash_len * 2, hash_len * 2);
+      memcpy (response, input + input_len - hash_len * 2, hash_len * 2);
       response[hash_len * 2 + 1] = '\0';
 
       res = cb_cram_md5 (sctx, username, challenge, response);
 
-      free(response);
+      free (response);
     }
   else if (cb_retrieve)
     {
@@ -317,70 +317,70 @@ _gsasl_cram_md5_server_step (Gsasl_session_ctx *sctx,
       char *normkey;
       int i;
 
-      md5h = gcry_md_open (GCRY_MD_MD5, GCRY_MD_FLAG_HMAC);
+      md5h = gcry_md_open (GCRY_MD_MD5, GCRY_MD_FLAG_SECURE|GCRY_MD_FLAG_HMAC);
       if (md5h == NULL)
 	{
-	  free(username);
+	  free (username);
 	  return GSASL_GCRYPT_ERROR;
 	}
 
-      res = cb_retrieve(sctx, username, NULL, NULL, NULL, &keylen);
+      res = cb_retrieve (sctx, username, NULL, NULL, NULL, &keylen);
       if (res != GSASL_OK)
 	return res;
-      key = malloc(keylen);
+      key = malloc (keylen);
       if (key == NULL)
 	return GSASL_MALLOC_ERROR;
-      res = cb_retrieve(sctx, username, NULL, NULL, key, &keylen);
+      res = cb_retrieve (sctx, username, NULL, NULL, key, &keylen);
       if (res != GSASL_OK)
 	{
-	  free(username);
-	  free(key);
+	  free (username);
+	  free (key);
 	  return res;
 	}
-      normkey = gsasl_utf8_nfkc_normalize (key, keylen);
-      free(key);
+      normkey = stringprep_utf8_nfkc_normalize (key, keylen);
+      free (key);
       if (normkey == NULL)
 	{
-	  free(username);
+	  free (username);
 	  return GSASL_UNICODE_NORMALIZATION_ERROR;
 	}
 
-      res = gcry_md_setkey (md5h, normkey, strlen(normkey));
-      free(normkey);
+      res = gcry_md_setkey (md5h, normkey, strlen (normkey));
+      free (normkey);
       if (res != GCRYERR_SUCCESS)
 	{
-	  free(username);
+	  free (username);
 	  return GSASL_GCRYPT_ERROR;
 	}
 
-      gcry_md_write (md5h, challenge, strlen(challenge));
-  
+      gcry_md_write (md5h, challenge, strlen (challenge));
+
       hash = gcry_md_read (md5h, GCRY_MD_MD5);
       if (hash == NULL)
 	{
-	  free(username);
+	  free (username);
 	  return GSASL_GCRYPT_ERROR;
 	}
 
       res = GSASL_OK;
       for (i = 0; i < hash_len; i++)
-	if ((input[input_len - hash_len*2 + 2*i + 1] != HEXCHAR(hash[i])) ||
-	    (input[input_len - hash_len*2 + 2*i + 0] != HEXCHAR(hash[i] >> 4)))
+	if ((input[input_len - hash_len * 2 + 2 * i + 1] != HEXCHAR (hash[i]))
+	    || (input[input_len - hash_len * 2 + 2 * i + 0] !=
+		HEXCHAR (hash[i] >> 4)))
 	  res = GSASL_AUTHENTICATION_ERROR;
     }
 
-  free(username);
+  free (username);
 
   return res;
 }
 
 int
-_gsasl_cram_md5_server_finish (Gsasl_session_ctx *sctx, 
-			       void *mech_data)
+_gsasl_cram_md5_server_finish (Gsasl_session_ctx * sctx, void *mech_data)
 {
   char *challenge = mech_data;
 
-  free(challenge);
+  free (challenge);
 
   return GSASL_OK;
 }
