@@ -42,16 +42,13 @@
  * code.
  **/
 int
-gsasl_client_step (Gsasl_session_ctx *xctx, 
-		   const char *input, 
-		   size_t input_len,
-		   char *output,
-		   size_t *output_len)
+gsasl_client_step (Gsasl_session_ctx * xctx,
+		   const char *input,
+		   size_t input_len, char *output, size_t * output_len)
 {
-  return xctx->mech->client.step(xctx, xctx->mech_data, 
-				 input, input_len, 
-				 output, output_len);
-  
+  return xctx->mech->client.step (xctx, xctx->mech_data,
+				  input, input_len, output, output_len);
+
 }
 
 /**
@@ -75,37 +72,33 @@ gsasl_client_step (Gsasl_session_ctx *xctx,
  * code.
  **/
 int
-gsasl_server_step (Gsasl_session_ctx *xctx, 
+gsasl_server_step (Gsasl_session_ctx * xctx,
 		   const char *input,
-		   size_t input_len,
-		   char *output,
-		   size_t *output_len)
+		   size_t input_len, char *output, size_t * output_len)
 {
-  return xctx->mech->server.step(xctx, xctx->mech_data, 
-				 input, input_len, 
-				 output, output_len);
+  return xctx->mech->server.step (xctx, xctx->mech_data,
+				  input, input_len, output, output_len);
 }
 
 static int
-_gsasl_session_step_base64 (Gsasl_session_ctx *xctx,
+_gsasl_session_step_base64 (Gsasl_session_ctx * xctx,
 			    const char *b64input,
 			    char *b64output,
-			    size_t b64output_len,
-			    int clientp)
+			    size_t b64output_len, int clientp)
 {
   size_t input_len, output_len;
   char *input, *output;
   int res;
 
-  if (b64input && strlen(b64input) > 0)
+  if (b64input && strlen (b64input) > 0)
     {
-      input_len = strlen(b64input) + 1;
-      input = (char*) malloc(input_len);
+      input_len = strlen (b64input) + 1;
+      input = (char *) malloc (input_len);
 
-      input_len = gsasl_base64_decode(b64input, input, input_len);
+      input_len = gsasl_base64_decode (b64input, input, input_len);
       if (input_len == -1)
 	{
-	  free(input);
+	  free (input);
 	  return GSASL_BASE64_ERROR;
 	}
     }
@@ -118,8 +111,8 @@ _gsasl_session_step_base64 (Gsasl_session_ctx *xctx,
   if (b64output && b64output_len > 0)
     {
       *b64output = '\0';
-      output_len = b64output_len; /* As good guess as any */
-      output = (char*) malloc(output_len);
+      output_len = b64output_len;	/* As good guess as any */
+      output = (char *) malloc (output_len);
     }
   else
     {
@@ -132,22 +125,22 @@ _gsasl_session_step_base64 (Gsasl_session_ctx *xctx,
   else
     res = gsasl_server_step (xctx, input, input_len, output, &output_len);
 
-  if (res == GSASL_NEEDS_MORE && output && output_len > 0)
+  if ((res == GSASL_OK || res == GSASL_NEEDS_MORE) && output && output_len > 0)
     {
-      output_len = gsasl_base64_encode(output, output_len, 
-				       b64output, b64output_len);
+      output_len = gsasl_base64_encode (output, output_len,
+					b64output, b64output_len);
       if (output_len == -1)
 	{
-	  free(output);
-	  free(input);
+	  free (output);
+	  free (input);
 	  return GSASL_BASE64_ERROR;
 	}
     }
 
   if (output != NULL)
-    free(output);
+    free (output);
   if (input != NULL)
-    free(input);
+    free (input);
 
   return res;
 }
@@ -165,12 +158,11 @@ _gsasl_session_step_base64 (Gsasl_session_ctx *xctx,
  * Return value: See gsasl_client_step().
  **/
 int
-gsasl_client_step_base64 (Gsasl_session_ctx *xctx,
+gsasl_client_step_base64 (Gsasl_session_ctx * xctx,
 			  const char *b64input,
-			  char *b64output,
-			  size_t b64output_len)
+			  char *b64output, size_t b64output_len)
 {
-  return _gsasl_session_step_base64 (xctx, b64input, b64output, 
+  return _gsasl_session_step_base64 (xctx, b64input, b64output,
 				     b64output_len, 1);
 }
 
@@ -187,11 +179,10 @@ gsasl_client_step_base64 (Gsasl_session_ctx *xctx,
  * Return value: See gsasl_server_step().
  **/
 int
-gsasl_server_step_base64 (Gsasl_session_ctx *xctx,
+gsasl_server_step_base64 (Gsasl_session_ctx * xctx,
 			  const char *b64input,
-			  char *b64output,
-			  size_t b64output_len)
+			  char *b64output, size_t b64output_len)
 {
-  return _gsasl_session_step_base64 (xctx, b64input, b64output, 
+  return _gsasl_session_step_base64 (xctx, b64input, b64output,
 				     b64output_len, 0);
 }
